## Aliyun ROS DIRECTMAIL Construct Library

This module is part of the AliCloud ROS Cloud Development Kit (ROS CDK) project.

```python
import * as DIRECTMAIL from '@alicloud/ros-cdk-directmail';
```
